@@ -1,184 +1,3 @@
-#' Pre-Defined Dose Frequencies
-#'
-#' @description
-#' These pre-defined dose frequencies are sourced from
-#' [CDISC](https://evs.nci.nih.gov/ftp1/CDISC/SDTM/SDTM%20Terminology.pdf). The
-#' number of rows to generate using `create_single_dose_dataset()` arguments
-#' `start_date` and `end_date` is derived from `DOSE_COUNT`, `DOSE_WINDOW`, and
-#' `CONVERSION_FACTOR` with appropriate functions from `lubridate`.
-#'
-#' @details
-#' `NCI_CODE` and `CDISC_VALUE` are included from the CDISC source for
-#' traceability.
-#'
-#' `DOSE_COUNT` represents the number of doses received in one single unit of
-#' `DOSE_WINDOW`. For example, for `CDISC_VALUE=="10 DAYS PER MONTH"`,
-#' `DOSE_WINDOW=="MONTH"` and `DOSE_COUNT==10`. Similarly, for
-#' `CDISC_VALUE=="EVERY 2 WEEKS"`, `DOSE_WINDOW=="WEEK"` and
-#' `DOSE_COUNT==0.5` (to yield one dose every two weeks).
-#'
-#' `CONVERSION_FACTOR` is used to convert `DOSE_WINDOW` units `"WEEK"`,
-#'  `"MONTH"`, and `"YEAR"` to the unit `"DAY"`.
-#'
-#' For example, for `CDISC_VALUE=="10 DAYS PER MONTH"`, `CONVERSION_FACTOR`
-#' is `0.0329`. One day of a month is assumed to be `1 / 30.4375` of a month (one
-#' day is assumed to be `1/365.25` of a year).
-#' Given only `start_date` and `end_date` in the aggregate dataset, `CONVERSION_FACTOR`
-#' is used to calculate specific dates for`start_date` and `end_date` in the
-#' resulting single dose dataset for the doses that occur. In such cases, doses
-#' are assumed to occur at evenly spaced increments over the interval.
-#'
-#'
-#' To see the entire table in the console, run `print(dose_freq_lookup)`.
-#'
-#' @seealso [create_single_dose_dataset()]
-#'
-#' @export
-#'
-#' @keywords metadata
-#' @family metadata
-#'
-#' @rdname dose_freq_lookup
-
-dose_freq_lookup <- tribble(
-  ~NCI_CODE, ~CDISC_VALUE,
-  "C64526", "1 TIME PER WEEK",
-  "C139179", "10 DAYS PER MONTH",
-  "C64497", "2 TIMES PER WEEK",
-  "C98861", "2 TIMES PER YEAR",
-  "C98859", "3 TIMES PER MONTH",
-  "C64528", "3 TIMES PER WEEK",
-  "C98860", "3 TIMES PER YEAR",
-  "C98852", "4 TIMES PER MONTH",
-  "C64531", "4 TIMES PER WEEK",
-  "C98853", "4 TIMES PER YEAR",
-  "C98849", "5 TIMES PER DAY",
-  "C98850", "5 TIMES PER MONTH",
-  "C85552", "5 TIMES PER WEEK",
-  "C98851", "5 TIMES PER YEAR",
-  "C98855", "6 TIMES PER DAY",
-  "C98856", "6 TIMES PER MONTH",
-  "C98857", "6 TIMES PER WEEK",
-  "C98858", "6 TIMES PER YEAR",
-  "C139180", "7 TIMES PER DAY",
-  "C98854", "7 TIMES PER WEEK",
-  "C139181", "8 TIMES PER DAY",
-  "C139182", "9 TIMES PER DAY",
-  "C64496", "BID",
-  "C71129", "BIM",
-  "C161332", "EVERY 12 WEEKS",
-  "C161336", "EVERY 16 WEEKS",
-  "C71127", "EVERY 2 WEEKS",
-  "C64535", "EVERY 3 WEEKS",
-  "C161333", "EVERY 3 YEARS",
-  "C64529", "EVERY 4 WEEKS",
-  "C103390", "EVERY 5 WEEKS",
-  "C161334", "EVERY 5 YEARS",
-  "C89788", "EVERY 6 WEEKS",
-  "C116149", "EVERY 7 WEEKS",
-  "C103389", "EVERY 8 WEEKS",
-  "C154484", "EVERY AFTERNOON",
-  "C160957", "EVERY EVENING",
-  "C67069", "EVERY WEEK",
-  "C74924", "PA",
-  "C64500", "Q10H",
-  "C64501", "Q11H",
-  "C64502", "Q12H",
-  "C64503", "Q13H",
-  "C64504", "Q14H",
-  "C64505", "Q15H",
-  "C64506", "Q16H",
-  "C64507", "Q17H",
-  "C64508", "Q18H",
-  "C64509", "Q19H",
-  "C64511", "Q20H",
-  "C64512", "Q21H",
-  "C64513", "Q22H",
-  "C64514", "Q23H",
-  "C64515", "Q24H",
-  "C64516", "Q2H",
-  "C64536", "Q2M",
-  "C89791", "Q36H",
-  "C64533", "Q3D",
-  "C64517", "Q3H",
-  "C64537", "Q3M",
-  "C139183", "Q45MIN",
-  "C89790", "Q48H",
-  "C64534", "Q4D",
-  "C64518", "Q4H",
-  "C64538", "Q4M",
-  "C71124", "Q5D",
-  "C64519", "Q5H",
-  "C161335", "Q6D",
-  "C64520", "Q6H",
-  "C89789", "Q6M",
-  "C174288", "Q72H",
-  "C139177", "Q7D",
-  "C64521", "Q7H",
-  "C64523", "Q8H",
-  "C64524", "Q9H",
-  "C64595", "QAM",
-  "C25473", "QD",
-  "C64510", "QH",
-  "C64593", "QHS",
-  "C64530", "QID",
-  "C64498", "QM",
-  "C139178", "QN",
-  "C64525", "QOD",
-  "C64525", "Q2D",
-  "C64596", "QPM",
-  "C64527", "TID"
-) %>%
-  mutate(
-    DOSE_COUNT = case_when(
-      str_detect(CDISC_VALUE, "PER [WMY]") ~
-        as.numeric(str_remove_all(CDISC_VALUE, "[\\D]")),
-      str_detect(CDISC_VALUE, "PER [D]") ~
-        24 / as.numeric(str_remove_all(CDISC_VALUE, "[\\D]")),
-      str_detect(CDISC_VALUE, "^Q\\d{1,2}(H|MIN)") ~
-        1 / as.numeric(str_remove_all(CDISC_VALUE, "[\\D]")),
-      str_detect(CDISC_VALUE, "^(Q|EVERY)\\s?\\d{1,2}") ~
-        1 / as.numeric(str_remove_all(CDISC_VALUE, "[\\D]")),
-      str_detect(CDISC_VALUE, "^EVERY (A|E|W)[:alpha:]+") ~ 1,
-      str_detect(CDISC_VALUE, "^Q(AM|PM|M|N|D|HS)|^PA$") ~ 1,
-      str_detect(CDISC_VALUE, "^QH$") ~ 1,
-      str_detect(CDISC_VALUE, "BIM") ~ 2,
-      str_detect(CDISC_VALUE, "BID") ~ 1 / 12,
-      str_detect(CDISC_VALUE, "TID") ~ 1 / 8,
-      str_detect(CDISC_VALUE, "QID") ~ 1 / 6,
-      str_detect(CDISC_VALUE, "QOD") ~ 0.5,
-    ),
-    DOSE_WINDOW = case_when(
-      str_detect(CDISC_VALUE, "EVERY \\d{1,2}|PER [WMY]") ~
-        str_remove_all(sub(".* (\\w+)$", "\\1", CDISC_VALUE), "S"),
-      str_detect(CDISC_VALUE, "^Q\\d{1,2}D$") ~ "DAY",
-      str_detect(CDISC_VALUE, "^Q\\d{1,2}M$") ~ "MONTH",
-      str_detect(CDISC_VALUE, "^Q\\d{0,2}H$|PER D") ~ "HOUR",
-      str_detect(CDISC_VALUE, "^Q\\d{1,2}MIN$") ~ "MINUTE",
-      CDISC_VALUE %in% c("EVERY AFTERNOON", "EVERY EVENING") ~ "DAY",
-      CDISC_VALUE %in% c("EVERY WEEK") ~ "WEEK",
-      CDISC_VALUE %in% c(
-        "QAM", "QPM", "QHS",
-        "QD", "QN", "QOD"
-      ) ~ "DAY",
-      CDISC_VALUE %in% c(
-        "BID", "TID", "QID"
-      ) ~ "HOUR",
-      CDISC_VALUE %in% c("QM", "BIM") ~ "MONTH",
-      CDISC_VALUE == "PA" ~ "YEAR",
-    )
-  ) %>%
-  mutate(
-    CONVERSION_FACTOR = case_when(
-      DOSE_WINDOW == "MINUTE" ~ 1,
-      DOSE_WINDOW == "HOUR" ~ 1,
-      DOSE_WINDOW == "DAY" ~ 1,
-      DOSE_WINDOW == "WEEK" ~ (1 / 7),
-      DOSE_WINDOW == "MONTH" ~ (1 / 30.4375),
-      DOSE_WINDOW == "YEAR" ~ (1 / 365.25),
-    )
-  )
-
 #' Create dataset of single doses
 #'
 #' Derives dataset of single dose from aggregate dose information. This may be
@@ -287,12 +106,12 @@ dose_freq_lookup <- tribble(
 #' library(dplyr)
 #'
 #' data <- tribble(
-#'   ~USUBJID, ~EXDOSFRQ, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
-#'   "P01", "Q2D", ymd("2021-01-01"), ymd_hms("2021-01-01 10:30:00"),
+#'   ~STUDYID, ~USUBJID, ~EXDOSFRQ, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
+#'   "STUDY01", "P01", "Q2D", ymd("2021-01-01"), ymd_hms("2021-01-01 10:30:00"),
 #'   ymd("2021-01-07"), ymd_hms("2021-01-07 11:30:00"),
-#'   "P01", "Q3D", ymd("2021-01-08"), ymd_hms("2021-01-08 12:00:00"),
+#'   "STUDY01", "P01", "Q3D", ymd("2021-01-08"), ymd_hms("2021-01-08 12:00:00"),
 #'   ymd("2021-01-14"), ymd_hms("2021-01-14 14:00:00"),
-#'   "P01", "EVERY 2 WEEKS", ymd("2021-01-15"), ymd_hms("2021-01-15 09:57:00"),
+#'   "STUDY01", "P01", "EVERY 2 WEEKS", ymd("2021-01-15"), ymd_hms("2021-01-15 09:57:00"),
 #'   ymd("2021-01-29"), ymd_hms("2021-01-29 10:57:00")
 #' )
 #'
@@ -307,10 +126,10 @@ dose_freq_lookup <- tribble(
 #' )
 #'
 #' data <- tribble(
-#'   ~USUBJID, ~EXDOSFRQ, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
-#'   "P01", "Q30MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
+#'   ~STUDYID, ~USUBJID, ~EXDOSFRQ, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
+#'   "STUDY01", "P01", "Q30MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
 #'   ymd("2021-01-01"), ymd_hms("2021-01-01T07:00:00"),
-#'   "P02", "Q90MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
+#'   "STUDY02", "P02", "Q90MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
 #'   ymd("2021-01-01"), ymd_hms("2021-01-01T09:00:00")
 #' )
 #'
@@ -323,12 +142,12 @@ dose_freq_lookup <- tribble(
 #' # Example with nominal time
 #'
 #' data <- tribble(
-#'   ~USUBJID, ~EXDOSFRQ, ~NFRLT, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
-#'   "P01", "BID", 0, ymd("2021-01-01"), ymd_hms("2021-01-01 08:00:00"),
+#'   ~STUDYID, ~USUBJID, ~EXDOSFRQ, ~NFRLT, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
+#'   "STUDY01", "P01", "BID", 0, ymd("2021-01-01"), ymd_hms("2021-01-01 08:00:00"),
 #'   ymd("2021-01-07"), ymd_hms("2021-01-07 20:00:00"),
-#'   "P01", "BID", 168, ymd("2021-01-08"), ymd_hms("2021-01-08 08:00:00"),
+#'   "STUDY01", "P01", "BID", 168, ymd("2021-01-08"), ymd_hms("2021-01-08 08:00:00"),
 #'   ymd("2021-01-14"), ymd_hms("2021-01-14 20:00:00"),
-#'   "P01", "BID", 336, ymd("2021-01-15"), ymd_hms("2021-01-15 08:00:00"),
+#'   "STUDY01", "P01", "BID", 336, ymd("2021-01-15"), ymd_hms("2021-01-15 08:00:00"),
 #'   ymd("2021-01-29"), ymd_hms("2021-01-29 20:00:00")
 #' )
 #'
@@ -397,7 +216,7 @@ dose_freq_lookup <- tribble(
 #' # Select valid dose records, non-missing `EXSTDTC` and `EXDOSE`.
 #' ex_mod <- ex %>%
 #'   filter(!is.na(EXSTDTC) & !is.na(EXDOSE)) %>%
-#'   derive_vars_merged(adsl_death, by_vars = exprs(STUDYID, USUBJID)) %>%
+#'   derive_vars_merged(adsl_death, by_vars = get_admiral_option("subject_keys")) %>%
 #'   # Example, set up missing `EXDOSFRQ` as QD daily dosing regime.
 #'   # Replace with study dosing regime per trial treatment.
 #'   mutate(EXDOSFRQ = if_else(is.na(EXDOSFRQ), "QD", EXDOSFRQ)) %>%
@@ -450,7 +269,8 @@ create_single_dose_dataset <- function(dataset,
                                        lookup_column = CDISC_VALUE,
                                        nominal_time = NULL,
                                        keep_source_vars = expr_c(
-                                         exprs(USUBJID), dose_freq, start_date, start_datetime,
+                                         get_admiral_option("subject_keys"), dose_freq,
+                                         start_date, start_datetime,
                                          end_date, end_datetime
                                        )) {
   dose_freq <- assert_symbol(enexpr(dose_freq))
