@@ -5,10 +5,9 @@
 #' function can derive a parameter indicating if there is measurable disease at
 #' baseline.
 #'
-#' @param dataset Input dataset
-#'
-#'   The variables specified for `by_vars` and the `PARAMCD` variable are
-#'   expected.
+#' @param dataset
+#'   `r roxygen_param_dataset(expected_vars = c("by_vars"))`
+#'   `PARAMCD` is expected as well.
 #'
 #' @param dataset_ref Reference dataset, e.g., ADSL
 #'
@@ -75,11 +74,6 @@
 #'
 #'   *Permitted Values*: a condition
 #'
-#' @param aval_fun Function to map character analysis value (`AVALC`) to numeric
-#'   analysis value (`AVAL`)
-#'
-#'   *Deprecated*, please use `set_values_to` instead.
-#'
 #' @param set_values_to Variables to set
 #'
 #'   A named list returned by `exprs()` defining the variables to be set for the
@@ -87,13 +81,9 @@
 #'   Baseline")` is expected. The values must be symbols, character strings,
 #'   numeric values, `NA`, or expressions.
 #'
-#' @param by_vars Variables to uniquely identify a group
+#' @param by_vars Grouping variables
 #'
-#'   A list of symbols created using `exprs()` is expected.
-#'
-#' @param dataset_adsl *Deprecated*, please use `dataset_ref` instead.
-#'
-#' @param subject_keys *Deprecated*, please use `by_vars` instead.
+#'   `r roxygen_param_by_vars()`
 #'
 #' @details
 #'   1. The additional dataset (`dataset_add`) is restricted to the observations
@@ -177,27 +167,8 @@ derive_param_exist_flag <- function(dataset = NULL,
                                     false_value = NA_character_,
                                     missing_value = NA_character_,
                                     filter_add = NULL,
-                                    aval_fun,
                                     by_vars = get_admiral_option("subject_keys"),
-                                    set_values_to,
-                                    dataset_adsl,
-                                    subject_keys) {
-  ### BEGIN DEPRECATION
-  if (!missing(dataset_adsl)) {
-    deprecate_stop(
-      "0.11.0", "derive_param_exist_flag(dataset_adsl = )",
-      "derive_param_exit_flag(dataset_ref = )"
-    )
-  }
-
-  if (!missing(subject_keys)) {
-    deprecate_stop(
-      "0.11.0", "derive_param_exist_flag(subject_keys = )",
-      "derive_param_exit_flag(by_vars = )"
-    )
-  }
-  ### END DEPRECATION
-
+                                    set_values_to) {
   # Check input parameters
   condition <- assert_filter_cond(enexpr(condition))
   assert_character_scalar(true_value)
@@ -217,15 +188,6 @@ derive_param_exist_flag <- function(dataset = NULL,
     assert_param_does_not_exist(dataset, set_values_to$PARAMCD)
   }
 
-  if (!missing(aval_fun)) {
-    assert_function(aval_fun)
-    deprecate_stop(
-      "0.11.0",
-      "derive_param_exist_flag(aval_fun = )",
-      "derive_param_exist_flag(set_values_to = )"
-    )
-  }
-
   # Create new observations
   new_obs <- derive_var_merged_exist_flag(
     dataset_ref,
