@@ -60,6 +60,15 @@
 #'
 #'   A list of symbols created using `exprs()` is expected.
 #'
+#' @param check_type Check uniqueness
+#'
+#'   If `"warning"`, `"message"`, or `"error"` is specified, the specified message is issued
+#'   if the observations of the source datasets are not unique with respect to the
+#'   by variables and the date and order specified in the `event_source()` and
+#'   `censor_source()` objects.
+#'
+#'   *Permitted Values*: `"none"`, `"message"`, `"warning"`, `"error"`
+#'
 #' @details The following steps are performed to create the observations of the
 #'   new parameter:
 #'
@@ -67,7 +76,7 @@
 #'
 #'   \enumerate{ \item For each event source dataset the observations as
 #'   specified by the `filter` element are selected. Then for each patient the
-#'   first observation (with respect to `date`) is selected.
+#'   first observation (with respect to `date` and `order`) is selected.
 #'
 #'   \item The `ADT` variable is set to the variable specified by the
 #'   \code{date} element. If the date variable is a datetime variable, only
@@ -81,14 +90,16 @@
 #'   \item The selected observations of all event source datasets are combined into a
 #'   single dataset.
 #'
-#'   \item For each patient the first observation (with respect to the `ADT`
-#'   variable) from the single dataset is selected. }
+#'   \item For each patient the first observation (with respect to the
+#'   `ADT`/`ADTM` variable) from the single dataset is selected. If there is
+#'   more than one event with the same date, the first event with respect to the
+#'   order of events in `event_conditions` is selected.}
 #'
 #'   **Deriving the censoring observations:**
 #'
 #'   \enumerate{ \item For each censoring source dataset the observations as
 #'   specified by the `filter` element are selected. Then for each patient the
-#'   last observation (with respect to `date`) is selected.
+#'   last observation (with respect to `date` and `order`) is selected.
 #'
 #'   \item The `ADT` variable is set to the variable specified by the
 #'   \code{date} element. If the date variable is a datetime variable, only
@@ -102,8 +113,10 @@
 #'   \item The selected observations of all censoring source datasets are
 #'   combined into a single dataset.
 #'
-#'   \item For each patient the last observation (with respect to the `ADT`
-#'   variable) from the single dataset is selected. }
+#'   \item For each patient the last observation (with respect to the
+#'   `ADT`/`ADTM` variable) from the single dataset is selected.  If there is
+#'   more than one censoring with the same date, the last censoring with respect
+#'   to the order of censorings in `censor_conditions` is selected.}
 #'
 #'   For each subject (as defined by the `subject_keys` parameter) an
 #'   observation is selected. If an event is available, the event observation is
@@ -263,9 +276,9 @@
 #'
 #' ae <- tribble(
 #'   ~USUBJID, ~AESTDTC,           ~AESEQ, ~AEDECOD,
-#'   "01",     "2021-01-03T10:56", 1,      "Flu",
-#'   "01",     "2021-03-04",       2,      "Cough",
-#'   "01",     "2021",             3,      "Flu"
+#'   "01",     "2021-01-03T10:56",      1, "Flu",
+#'   "01",     "2021-03-04",            2, "Cough",
+#'   "01",     "2021",                  3, "Flu"
 #' ) %>%
 #'   mutate(STUDYID = "AB42")
 #'
@@ -313,6 +326,50 @@
 #'   )
 #' ) %>%
 #'   select(USUBJID, STARTDT, PARAMCD, PARAM, ADT, CNSR, SRCSEQ)
+#'
+#' # Resolve tie when serious AE share a date by sorting with order argument
+#' adsl <- tribble(
+#'   ~USUBJID, ~TRTSDT,           ~EOSDT,
+#'   "01",     ymd("2020-12-06"), ymd("2021-03-06"),
+#'   "02",     ymd("2021-01-16"), ymd("2021-02-03")
+#' ) %>% mutate(STUDYID = "AB42")
+#'
+#' ae <- tribble(
+#'   ~USUBJID, ~AESTDTC,     ~AESEQ, ~AESER, ~AEDECOD,
+#'   "01",     "2021-01-03",      1, "Y",    "Flu",
+#'   "01",     "2021-01-03",      2, "Y",    "Cough",
+#'   "01",     "2021-01-20",      3, "N",    "Headache"
+#' ) %>% mutate(
+#'   AESTDT = ymd(AESTDTC),
+#'   STUDYID = "AB42"
+#' )
+#'
+#' derive_param_tte(
+#'   dataset_adsl = adsl,
+#'   start_date = TRTSDT,
+#'   source_datasets = list(adsl = adsl, ae = ae),
+#'   event_conditions = list(event_source(
+#'     dataset_name = "ae",
+#'     date = AESTDT,
+#'     set_values_to = exprs(
+#'       EVENTDESC = "Serious AE",
+#'       SRCSEQ = AESEQ
+#'     ),
+#'     filter = AESER == "Y",
+#'     order = exprs(AESEQ)
+#'   )),
+#'   censor_conditions = list(censor_source(
+#'     dataset_name = "adsl",
+#'     date = EOSDT,
+#'     censor = 1,
+#'     set_values_to = exprs(EVENTDESC = "End of Study")
+#'   )),
+#'   set_values_to = exprs(
+#'     PARAMCD = "TTSAE",
+#'     PARAM = "Time to First Serious AE"
+#'   )
+#' )
+#'
 derive_param_tte <- function(dataset = NULL,
                              dataset_adsl,
                              source_datasets,
@@ -322,8 +379,14 @@ derive_param_tte <- function(dataset = NULL,
                              censor_conditions,
                              create_datetime = FALSE,
                              set_values_to,
-                             subject_keys = get_admiral_option("subject_keys")) {
+                             subject_keys = get_admiral_option("subject_keys"),
+                             check_type = "warning") {
   # checking and quoting #
+  check_type <- assert_character_scalar(
+    check_type,
+    values = c("warning", "message", "error", "none"),
+    case_sensitive = FALSE
+  )
   assert_data_frame(dataset, optional = TRUE)
   assert_vars(by_vars, optional = TRUE)
   start_date <- assert_symbol(enexpr(start_date))
@@ -373,8 +436,8 @@ derive_param_tte <- function(dataset = NULL,
       by_vars = by_vars
     )
   }
-
   tmp_event <- get_new_tmp_var(dataset)
+
   # determine events #
   event_data <- filter_date_sources(
     sources = event_conditions,
@@ -382,7 +445,8 @@ derive_param_tte <- function(dataset = NULL,
     by_vars = by_vars,
     create_datetime = create_datetime,
     subject_keys = subject_keys,
-    mode = "first"
+    mode = "first",
+    check_type = check_type
   ) %>%
     mutate(!!tmp_event := 1L)
 
@@ -393,7 +457,8 @@ derive_param_tte <- function(dataset = NULL,
     by_vars = by_vars,
     create_datetime = create_datetime,
     subject_keys = subject_keys,
-    mode = "last"
+    mode = "last",
+    check_type = check_type
   ) %>%
     mutate(!!tmp_event := 0L)
 
@@ -436,7 +501,8 @@ derive_param_tte <- function(dataset = NULL,
     bind_rows(event_data, censor_data),
     by_vars = expr_c(subject_keys, by_vars),
     order = exprs(!!tmp_event),
-    mode = "last"
+    mode = "last",
+    check_type = "none"
   ) %>%
     inner_join(
       adsl,
@@ -503,7 +569,15 @@ derive_param_tte <- function(dataset = NULL,
 #'   respect to the date is included in the output dataset. If `"last"` is
 #'   specified, the last observation is included in the output dataset.
 #'
-#'   Permitted Values:  `"first"`, `"last"`
+#'   *Permitted Values*:  `"first"`, `"last"`
+#'
+#' @param check_type Check uniqueness
+#'
+#'   If `"warning"`, `"message"`, or `"error"` is specified, the specified message is issued
+#'   if the observations of the source datasets are not unique with respect to the
+#'   by variables and the date and order specified in the `tte_source()` objects.
+#'
+#'   *Permitted Values*: `"none"`, `"warning"`, `"error"`, `"message"`
 #'
 #' @details The following steps are performed to create the output dataset:
 #'
@@ -529,7 +603,7 @@ derive_param_tte <- function(dataset = NULL,
 #' @return A dataset with one observation per subject as described in the
 #'   "Details" section.
 #'
-#' @noRd
+#' @keywords internal
 #'
 #' @examples
 #' library(tibble)
@@ -565,20 +639,22 @@ derive_param_tte <- function(dataset = NULL,
 #'   )
 #' )
 #'
-#' filter_date_sources(
+#' admiral:::filter_date_sources(
 #'   sources = list(ttae),
 #'   source_datasets = list(adsl = adsl, ae = ae),
 #'   by_vars = exprs(AEDECOD),
 #'   create_datetime = FALSE,
 #'   subject_keys = get_admiral_option("subject_keys"),
-#'   mode = "first"
+#'   mode = "first",
+#'   check_type = "none"
 #' )
 filter_date_sources <- function(sources,
                                 source_datasets,
                                 by_vars,
                                 create_datetime = FALSE,
                                 subject_keys,
-                                mode) {
+                                mode,
+                                check_type = "none") {
   assert_list_of(sources, "tte_source")
   assert_list_of(source_datasets, "data.frame")
   assert_logical_scalar(create_datetime)
@@ -613,17 +689,34 @@ filter_date_sources <- function(sources,
       var = !!source_date_var,
       dataset_name = sources[[i]]$dataset_name
     )
-    data[[i]] <- source_dataset %>%
-      filter_if(sources[[i]]$filter) %>%
-      filter_extreme(
-        order = exprs(!!source_date_var),
-        by_vars = expr_c(subject_keys, by_vars),
-        mode = mode,
-        check_type = "none"
-      )
-
+    # wrap filter_extreme in tryCatch to catch duplicate records and create a message
+    data[[i]] <- rlang::try_fetch(
+      {
+        source_dataset %>%
+          filter_if(sources[[i]]$filter) %>%
+          filter_extreme(
+            order = expr_c(exprs(!!source_date_var), sources[[i]]$order),
+            by_vars = expr_c(subject_keys, by_vars),
+            mode = mode,
+            check_type = check_type
+          )
+      },
+      duplicate_records = function(cnd) {
+        cnd_funs <- list(message = cli_inform, warning = cli_warn, error = cli_abort)
+        cnd_funs[[check_type]](
+          c(
+            paste(
+              "Dataset {.val {sources[[i]]$dataset_name}} contains duplicate",
+              "records with respect to {.var {cnd$by_vars}}"
+            ),
+            i = "Run {.run admiral::get_duplicates_dataset()} to access the duplicate records"
+          ),
+          class = class(cnd))
+        cnd_muffle(cnd)
+        zap()
+      }
+    )
     # add date variable and accompanying variables
-
     if (create_datetime) {
       date_derv <- exprs(!!date_var := as_datetime(!!source_date_var))
     } else {
@@ -637,6 +730,7 @@ filter_date_sources <- function(sources,
       !!!sources[[i]]$set_values_to,
       CNSR = sources[[i]]$censor,
       !!!date_derv,
+      tmp_source_nr = i,
       .keep = "none"
     )
   }
@@ -647,10 +741,11 @@ filter_date_sources <- function(sources,
     filter(!is.na(!!date_var)) %>%
     filter_extreme(
       by_vars = expr_c(subject_keys, by_vars),
-      order = exprs(!!date_var),
+      order = exprs(!!date_var, tmp_source_nr),
       mode = mode,
       check_type = "none"
-    )
+    ) %>%
+    select(-tmp_source_nr)
 }
 
 #' Add By Groups to All Datasets if Necessary
@@ -782,6 +877,12 @@ extend_source_datasets <- function(source_datasets,
 #'   SRCDOM = "ADSL", SRCVAR = "DTHDT")`. The values must be a symbol, a
 #'   character string, a numeric value, an expression, or `NA`.
 #'
+#' @param order Sort order
+#'
+#'   An optional named list returned by `exprs()` defining additional variables
+#'   that the source dataset is sorted on after `date`.
+#'
+#'   *Permitted Values:* list of variables created by `exprs()` e.g. `exprs(ASEQ)`.
 #'
 #' @keywords source_specifications
 #' @family source_specifications
@@ -793,7 +894,8 @@ tte_source <- function(dataset_name,
                        filter = NULL,
                        date,
                        censor = 0,
-                       set_values_to = NULL) {
+                       set_values_to = NULL,
+                       order = order) {
   out <- list(
     dataset_name = assert_character_scalar(dataset_name),
     filter = assert_filter_cond(enexpr(filter), optional = TRUE),
@@ -803,7 +905,8 @@ tte_source <- function(dataset_name,
       set_values_to,
       named = TRUE,
       optional = TRUE
-    )
+    ),
+    order = order
   )
   class(out) <- c("tte_source", "source", "list")
   out
@@ -844,13 +947,15 @@ tte_source <- function(dataset_name,
 event_source <- function(dataset_name,
                          filter = NULL,
                          date,
-                         set_values_to = NULL) {
+                         set_values_to = NULL,
+                         order = NULL) {
   out <- tte_source(
     dataset_name = assert_character_scalar(dataset_name),
     filter = !!enexpr(filter),
     date = !!assert_expr(enexpr(date)),
     censor = 0,
-    set_values_to = set_values_to
+    set_values_to = set_values_to,
+    order = order
   )
   class(out) <- c("event_source", class(out))
   out
@@ -891,13 +996,15 @@ censor_source <- function(dataset_name,
                           filter = NULL,
                           date,
                           censor = 1,
-                          set_values_to = NULL) {
+                          set_values_to = NULL,
+                          order = NULL) {
   out <- tte_source(
     dataset_name = assert_character_scalar(dataset_name),
     filter = !!enexpr(filter),
     date = !!assert_expr(enexpr(date)),
     censor = assert_integer_scalar(censor, subset = "positive"),
-    set_values_to = set_values_to
+    set_values_to = set_values_to,
+    order = order
   )
   class(out) <- c("censor_source", class(out))
   out
