@@ -7,8 +7,9 @@
 #'
 #' @param dataset_merge Dataset to transpose and merge
 #'
-#'   The variables specified by the `by_vars`, `key_var` and `value_var` parameters
-#'   are expected
+#'   The variables specified by the `by_vars`, `id_vars`, `key_var` and
+#'   `value_var` arguments are expected. The variables `by_vars`, `id_vars`,
+#'   `key_var` have to be a unique key.
 #'
 #' @param by_vars Grouping variables
 #'
@@ -35,17 +36,18 @@
 #'   <https://dplyr.tidyverse.org/reference/mutate-joins.html#arguments> for
 #'   more details.
 #'
-#'   Permitted Values for `relationship`: `"one-to-one"`, `"one-to-many"`,
-#'   `"many-to-one"`, `"many-to-many"`, `NULL`.
+#'   *Permitted Values*: `"one-to-one"`, `"one-to-many"`, `"many-to-one"`,
+#'   `"many-to-many"`, `NULL`
 #'
 #' @details
 #' After filtering `dataset_merge` based upon the condition provided in `filter`, this
 #' dataset is transposed and subsequently merged onto `dataset` using `by_vars` as
 #' keys.
 #'
-#'
 #' @return The input dataset with transposed variables from `dataset_merge` added
 #'
+#' @seealso [derive_vars_atc()]
+#'
 #' @family der_gen
 #' @keywords der_gen
 #'
@@ -56,33 +58,33 @@
 #' library(dplyr, warn.conflicts = FALSE)
 #'
 #' cm <- tribble(
-#'   ~USUBJID, ~CMGRPID, ~CMREFID, ~CMDECOD,
-#'   "BP40257-1001", "14", "1192056", "PARACETAMOL",
-#'   "BP40257-1001", "18", "2007001", "SOLUMEDROL",
-#'   "BP40257-1002", "19", "2791596", "SPIRONOLACTONE"
+#'   ~USUBJID,       ~CMGRPID, ~CMREFID,  ~CMDECOD,
+#'   "BP40257-1001", "14",     "1192056", "PARACETAMOL",
+#'   "BP40257-1001", "18",     "2007001", "SOLUMEDROL",
+#'   "BP40257-1002", "19",     "2791596", "SPIRONOLACTONE"
 #' )
 #' facm <- tribble(
-#'   ~USUBJID, ~FAGRPID, ~FAREFID, ~FATESTCD, ~FASTRESC,
-#'   "BP40257-1001", "1", "1192056", "CMATC1CD", "N",
-#'   "BP40257-1001", "1", "1192056", "CMATC2CD", "N02",
-#'   "BP40257-1001", "1", "1192056", "CMATC3CD", "N02B",
-#'   "BP40257-1001", "1", "1192056", "CMATC4CD", "N02BE",
-#'   "BP40257-1001", "1", "2007001", "CMATC1CD", "D",
-#'   "BP40257-1001", "1", "2007001", "CMATC2CD", "D10",
-#'   "BP40257-1001", "1", "2007001", "CMATC3CD", "D10A",
-#'   "BP40257-1001", "1", "2007001", "CMATC4CD", "D10AA",
-#'   "BP40257-1001", "2", "2007001", "CMATC1CD", "D",
-#'   "BP40257-1001", "2", "2007001", "CMATC2CD", "D07",
-#'   "BP40257-1001", "2", "2007001", "CMATC3CD", "D07A",
-#'   "BP40257-1001", "2", "2007001", "CMATC4CD", "D07AA",
-#'   "BP40257-1001", "3", "2007001", "CMATC1CD", "H",
-#'   "BP40257-1001", "3", "2007001", "CMATC2CD", "H02",
-#'   "BP40257-1001", "3", "2007001", "CMATC3CD", "H02A",
-#'   "BP40257-1001", "3", "2007001", "CMATC4CD", "H02AB",
-#'   "BP40257-1002", "1", "2791596", "CMATC1CD", "C",
-#'   "BP40257-1002", "1", "2791596", "CMATC2CD", "C03",
-#'   "BP40257-1002", "1", "2791596", "CMATC3CD", "C03D",
-#'   "BP40257-1002", "1", "2791596", "CMATC4CD", "C03DA"
+#'   ~USUBJID,       ~FAGRPID, ~FAREFID,  ~FATESTCD,  ~FASTRESC,
+#'   "BP40257-1001", "1",      "1192056", "CMATC1CD", "N",
+#'   "BP40257-1001", "1",      "1192056", "CMATC2CD", "N02",
+#'   "BP40257-1001", "1",      "1192056", "CMATC3CD", "N02B",
+#'   "BP40257-1001", "1",      "1192056", "CMATC4CD", "N02BE",
+#'   "BP40257-1001", "1",      "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "1",      "2007001", "CMATC2CD", "D10",
+#'   "BP40257-1001", "1",      "2007001", "CMATC3CD", "D10A",
+#'   "BP40257-1001", "1",      "2007001", "CMATC4CD", "D10AA",
+#'   "BP40257-1001", "2",      "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "2",      "2007001", "CMATC2CD", "D07",
+#'   "BP40257-1001", "2",      "2007001", "CMATC3CD", "D07A",
+#'   "BP40257-1001", "2",      "2007001", "CMATC4CD", "D07AA",
+#'   "BP40257-1001", "3",      "2007001", "CMATC1CD", "H",
+#'   "BP40257-1001", "3",      "2007001", "CMATC2CD", "H02",
+#'   "BP40257-1001", "3",      "2007001", "CMATC3CD", "H02A",
+#'   "BP40257-1001", "3",      "2007001", "CMATC4CD", "H02AB",
+#'   "BP40257-1002", "1",      "2791596", "CMATC1CD", "C",
+#'   "BP40257-1002", "1",      "2791596", "CMATC2CD", "C03",
+#'   "BP40257-1002", "1",      "2791596", "CMATC3CD", "C03D",
+#'   "BP40257-1002", "1",      "2791596", "CMATC4CD", "C03DA"
 #' )
 #'
 #' cm %>%
@@ -116,8 +118,24 @@ derive_vars_transposed <- function(dataset,
     optional = TRUE
   )
 
+  dataset_merge <- filter_if(dataset_merge, filter)
+
+  # check for duplicates in dataset_merge as these will create list columns,
+  # which is not acceptable for ADaM datasets
+  signal_duplicate_records(
+    dataset_merge,
+    by_vars = c(by_vars, id_vars, exprs(!!key_var)),
+    msg = c(
+      paste(
+        "Dataset {.arg dataset_merge} contains duplicate records with respect to",
+        "{.var {by_vars}}"
+      ),
+      "Please check data and {.arg by_vars}, {.arg id_vars}, and {.arg key_var} arguments."
+    ),
+    class = "merge_duplicates"
+  )
+
   dataset_transposed <- dataset_merge %>%
-    filter_if(filter) %>%
     pivot_wider(
       names_from = !!key_var,
       values_from = !!value_var,
@@ -164,118 +182,6 @@ derive_vars_transposed <- function(dataset,
         ),
         call = parent.frame(n = 4)
       )
-    },
-    "dplyr_error_join_relationship_one_to_many" = function(cnd) {
-      cli_abort(
-        message = c(
-          str_replace(
-            str_replace(
-              cnd$message, "`x`", "`dataset`"
-            ), "`y`", "the transposed `dataset_merge`"
-          ),
-          i = str_replace(
-            str_replace(
-              cnd$body, "`x`", "`dataset`"
-            ), "`y`", "the transposed `dataset_merge`"
-          )
-        ),
-        call = parent.frame(n = 4)
-      )
     }
   )
 }
-
-#' Derive ATC Class Variables
-#'
-#' @description Add Anatomical Therapeutic Chemical class variables from `FACM` to `ADCM`.
-#'
-#' **Note:** This is a wrapper function for the more generic `derive_vars_transposed()`.
-#'
-#' @param dataset
-#'   `r roxygen_param_dataset(expected_vars = c("by_vars"))`
-#'
-#' @param dataset_facm FACM dataset
-#'
-#'   The variables specified by the `by_vars` and `value_var` parameters,
-#'   `FAGRPID` and `FATESTCD` are required
-#'
-#' @param by_vars Grouping variables
-#'
-#'  Keys used to merge `dataset_facm` with `dataset`.
-#'
-#' @param id_vars ID variables
-#'
-#'  Variables (excluding by_vars) that uniquely identify each observation in `dataset_merge`.
-#'
-#' `r roxygen_param_by_vars()`
-#'
-#' @param value_var The variable of `dataset_facm` containing the values of the
-#'   transposed variables
-#'
-#'   Default: `FASTRESC`
-#'
-#'
-#' @return The input dataset with ATC variables added
-#'
-#' @family der_occds
-#' @keywords der_occds
-#'
-#' @export
-#'
-#' @examples
-#' library(tibble)
-#'
-#' cm <- tribble(
-#'   ~USUBJID, ~CMGRPID, ~CMREFID, ~CMDECOD,
-#'   "BP40257-1001", "14", "1192056", "PARACETAMOL",
-#'   "BP40257-1001", "18", "2007001", "SOLUMEDROL",
-#'   "BP40257-1002", "19", "2791596", "SPIRONOLACTONE"
-#' )
-#' facm <- tribble(
-#'   ~USUBJID, ~FAGRPID, ~FAREFID, ~FATESTCD, ~FASTRESC,
-#'   "BP40257-1001", "1", "1192056", "CMATC1CD", "N",
-#'   "BP40257-1001", "1", "1192056", "CMATC2CD", "N02",
-#'   "BP40257-1001", "1", "1192056", "CMATC3CD", "N02B",
-#'   "BP40257-1001", "1", "1192056", "CMATC4CD", "N02BE",
-#'   "BP40257-1001", "1", "2007001", "CMATC1CD", "D",
-#'   "BP40257-1001", "1", "2007001", "CMATC2CD", "D10",
-#'   "BP40257-1001", "1", "2007001", "CMATC3CD", "D10A",
-#'   "BP40257-1001", "1", "2007001", "CMATC4CD", "D10AA",
-#'   "BP40257-1001", "2", "2007001", "CMATC1CD", "D",
-#'   "BP40257-1001", "2", "2007001", "CMATC2CD", "D07",
-#'   "BP40257-1001", "2", "2007001", "CMATC3CD", "D07A",
-#'   "BP40257-1001", "2", "2007001", "CMATC4CD", "D07AA",
-#'   "BP40257-1001", "3", "2007001", "CMATC1CD", "H",
-#'   "BP40257-1001", "3", "2007001", "CMATC2CD", "H02",
-#'   "BP40257-1001", "3", "2007001", "CMATC3CD", "H02A",
-#'   "BP40257-1001", "3", "2007001", "CMATC4CD", "H02AB",
-#'   "BP40257-1002", "1", "2791596", "CMATC1CD", "C",
-#'   "BP40257-1002", "1", "2791596", "CMATC2CD", "C03",
-#'   "BP40257-1002", "1", "2791596", "CMATC3CD", "C03D",
-#'   "BP40257-1002", "1", "2791596", "CMATC4CD", "C03DA"
-#' )
-#'
-#' derive_vars_atc(cm, facm)
-derive_vars_atc <- function(dataset,
-                            dataset_facm,
-                            by_vars = exprs(USUBJID, CMREFID = FAREFID),
-                            id_vars = NULL,
-                            value_var = FASTRESC) {
-  value_var <- assert_symbol(enexpr(value_var))
-  assert_vars(by_vars)
-  assert_vars(id_vars, optional = TRUE)
-  assert_data_frame(dataset, required_vars = replace_values_by_names(by_vars))
-  assert_data_frame(dataset_facm, required_vars = exprs(!!!by_vars, !!value_var, FAGRPID, FATESTCD))
-
-  dataset %>%
-    derive_vars_transposed(
-      select(dataset_facm, !!!unname(by_vars), !!value_var, FAGRPID, FATESTCD),
-      by_vars = by_vars,
-      id_vars = id_vars,
-      key_var = FATESTCD,
-      value_var = !!value_var,
-      filter = str_detect(FATESTCD, "^CMATC[1-4](CD)?$")
-    ) %>%
-    select(-starts_with("FA")) %>%
-    rename_with(.fn = ~ str_remove(.x, "^CM"), .cols = starts_with("CMATC"))
-}
