@@ -47,3 +47,13 @@ roxygen_order_na_handling <- function() {
     "[Sort Order](../articles/generic.html#sort_order)."
   )
 }
+
+roxygen_save_memory <- function() {
+  paste(
+    "**Note:** This function creates temporary datasets which may be much bigger",
+    "than the input datasets. If this causes memory issues, please try setting",
+    "the admiral option `save_memory` to `TRUE` (see `set_admiral_options()`).",
+    "This reduces the memory consumption but increases the run-time.",
+    sep = "\n"
+  )
+}
