@@ -13,11 +13,11 @@ library(pharmaversesdtm)
 library(lubridate)
 library(stringr)
 
-data("dm")
-data("ds")
-data("ex")
-data("ae")
-data("lb")
+dm <- pharmaversesdtm::dm
+ds <- pharmaversesdtm::ds
+ex <- pharmaversesdtm::ex
+ae <- pharmaversesdtm::ae
+lb <- pharmaversesdtm::lb
 
 dm <- convert_blanks_to_na(dm)
 ds <- convert_blanks_to_na(ds)
@@ -409,30 +409,54 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
-format_agegr1 <- function(var_input) {
-  case_when(
-    var_input < 18 ~ "<18",
-    between(var_input, 18, 64) ~ "18-64",
-    var_input > 64 ~ ">64",
-    TRUE ~ "Missing"
-  )
-}
+# create lookup tables
+agegr1_lookup <- exprs(
+  ~condition,           ~AGEGR1,
+  AGE < 18,               "<18",
+  between(AGE, 18, 64), "18-64",
+  AGE > 64,               ">64",
+  is.na(AGE),         "Missing"
+)
 
-format_region1 <- function(var_input) {
-  case_when(
-    var_input %in% c("CAN", "USA") ~ "North America",
-    !is.na(var_input) ~ "Rest of the World",
-    TRUE ~ "Missing"
-  )
-}
+region1_lookup <- exprs(
+  ~condition,                          ~REGION1,
+  COUNTRY %in% c("CAN", "USA"), "North America",
+  !is.na(COUNTRY),          "Rest of the World",
+  is.na(COUNTRY),                     "Missing"
+)
 
 ## ----eval=TRUE----------------------------------------------------------------
 adsl <- adsl %>%
-  mutate(
-    AGEGR1 = format_agegr1(AGE),
-    REGION1 = format_region1(COUNTRY)
+  derive_vars_cat(
+    definition = agegr1_lookup
+  ) %>%
+  derive_vars_cat(
+    definition = region1_lookup
   )
 
+## -----------------------------------------------------------------------------
+#  format_agegr1 <- function(var_input) {
+#    case_when(
+#      var_input < 18 ~ "<18",
+#      between(var_input, 18, 64) ~ "18-64",
+#      var_input > 64 ~ ">64",
+#      TRUE ~ "Missing"
+#    )
+#  }
+#  format_region1 <- function(var_input) {
+#    case_when(
+#      var_input %in% c("CAN", "USA") ~ "North America",
+#      !is.na(var_input) ~ "Rest of the World",
+#      TRUE ~ "Missing"
+#    )
+#  }
+#  
+#  adsl %>%
+#    mutate(
+#      AGEGR1 = format_agegr1(AGE),
+#      REGION1 = format_region1(COUNTRY)
+#    )
+
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adsl,
