@@ -15,11 +15,10 @@ library(pharmaversesdtm)
 library(lubridate)
 
 ## -----------------------------------------------------------------------------
-data("ae")
-data("admiral_adsl")
+ae <- pharmaversesdtm::ae
+adsl <- admiral::admiral_adsl
 
 ae <- convert_blanks_to_na(ae)
-adsl <- admiral_adsl
 
 ## ----echo=FALSE---------------------------------------------------------------
 ae <- filter(ae, USUBJID %in% c("01-701-1015", "01-701-1023", "01-703-1086", "01-703-1096", "01-707-1037", "01-716-1024"))
