@@ -12,11 +12,11 @@ library(dplyr, warn.conflicts = FALSE)
 library(pharmaversesdtm)
 library(lubridate)
 
-data("ae")
-data("admiral_adsl")
+ae <- pharmaversesdtm::ae
+adsl <- admiral::admiral_adsl
+ex_single <- admiral::ex_single
 
 ae <- convert_blanks_to_na(ae)
-adsl <- admiral_adsl
 
 ## ----echo = FALSE-------------------------------------------------------------
 ae <- filter(ae, USUBJID %in% c("01-701-1015", "01-701-1023", "01-703-1086", "01-703-1096", "01-707-1037", "01-716-1024"))
@@ -91,36 +91,36 @@ dataset_vignette(
 
 ## ----eval=TRUE----------------------------------------------------------------
 cm <- tibble::tribble(
-  ~USUBJID,       ~CMGRPID, ~CMREFID,  ~CMDECOD,
-  "BP40257-1001",     "14", "1192056", "PARACETAMOL",
-  "BP40257-1001",     "18", "2007001", "SOLUMEDROL",
-  "BP40257-1002",     "19", "2791596", "SPIRONOLACTONE"
+  ~STUDYID,  ~USUBJID,       ~CMGRPID, ~CMREFID,  ~CMDECOD,
+  "STUDY01", "BP40257-1001", "14",     "1192056", "PARACETAMOL",
+  "STUDY01", "BP40257-1001", "18",     "2007001", "SOLUMEDROL",
+  "STUDY01", "BP40257-1002", "19",     "2791596", "SPIRONOLACTONE"
 )
 facm <- tibble::tribble(
-  ~USUBJID,       ~FAGRPID,  ~FAREFID, ~FATESTCD,  ~FASTRESC,
-  "BP40257-1001",      "1", "1192056", "CMATC1CD",       "N",
-  "BP40257-1001",      "1", "1192056", "CMATC2CD",     "N02",
-  "BP40257-1001",      "1", "1192056", "CMATC3CD",    "N02B",
-  "BP40257-1001",      "1", "1192056", "CMATC4CD",   "N02BE",
-  "BP40257-1001",      "1", "2007001", "CMATC1CD",       "D",
-  "BP40257-1001",      "1", "2007001", "CMATC2CD",     "D10",
-  "BP40257-1001",      "1", "2007001", "CMATC3CD",    "D10A",
-  "BP40257-1001",      "1", "2007001", "CMATC4CD",   "D10AA",
-  "BP40257-1001",      "2", "2007001", "CMATC1CD",       "D",
-  "BP40257-1001",      "2", "2007001", "CMATC2CD",     "D07",
-  "BP40257-1001",      "2", "2007001", "CMATC3CD",    "D07A",
-  "BP40257-1001",      "2", "2007001", "CMATC4CD",   "D07AA",
-  "BP40257-1001",      "3", "2007001", "CMATC1CD",       "H",
-  "BP40257-1001",      "3", "2007001", "CMATC2CD",     "H02",
-  "BP40257-1001",      "3", "2007001", "CMATC3CD",    "H02A",
-  "BP40257-1001",      "3", "2007001", "CMATC4CD",   "H02AB",
-  "BP40257-1002",      "1", "2791596", "CMATC1CD",       "C",
-  "BP40257-1002",      "1", "2791596", "CMATC2CD",     "C03",
-  "BP40257-1002",      "1", "2791596", "CMATC3CD",    "C03D",
-  "BP40257-1002",      "1", "2791596", "CMATC4CD",   "C03DA"
+  ~STUDYID,  ~USUBJID,       ~FAGRPID, ~FAREFID,  ~FATESTCD,  ~FASTRESC,
+  "STUDY01", "BP40257-1001", "1",      "1192056", "CMATC1CD", "N",
+  "STUDY01", "BP40257-1001", "1",      "1192056", "CMATC2CD", "N02",
+  "STUDY01", "BP40257-1001", "1",      "1192056", "CMATC3CD", "N02B",
+  "STUDY01", "BP40257-1001", "1",      "1192056", "CMATC4CD", "N02BE",
+  "STUDY01", "BP40257-1001", "1",      "2007001", "CMATC1CD", "D",
+  "STUDY01", "BP40257-1001", "1",      "2007001", "CMATC2CD", "D10",
+  "STUDY01", "BP40257-1001", "1",      "2007001", "CMATC3CD", "D10A",
+  "STUDY01", "BP40257-1001", "1",      "2007001", "CMATC4CD", "D10AA",
+  "STUDY01", "BP40257-1001", "2",      "2007001", "CMATC1CD", "D",
+  "STUDY01", "BP40257-1001", "2",      "2007001", "CMATC2CD", "D07",
+  "STUDY01", "BP40257-1001", "2",      "2007001", "CMATC3CD", "D07A",
+  "STUDY01", "BP40257-1001", "2",      "2007001", "CMATC4CD", "D07AA",
+  "STUDY01", "BP40257-1001", "3",      "2007001", "CMATC1CD", "H",
+  "STUDY01", "BP40257-1001", "3",      "2007001", "CMATC2CD", "H02",
+  "STUDY01", "BP40257-1001", "3",      "2007001", "CMATC3CD", "H02A",
+  "STUDY01", "BP40257-1001", "3",      "2007001", "CMATC4CD", "H02AB",
+  "STUDY01", "BP40257-1002", "1",      "2791596", "CMATC1CD", "C",
+  "STUDY01", "BP40257-1002", "1",      "2791596", "CMATC2CD", "C03",
+  "STUDY01", "BP40257-1002", "1",      "2791596", "CMATC3CD", "C03D",
+  "STUDY01", "BP40257-1002", "1",      "2791596", "CMATC4CD", "C03DA"
 )
 
-derive_vars_atc(cm, facm)
+derive_vars_atc(cm, dataset_facm = facm, id_vars = exprs(FAGRPID))
 
 ## ----eval=TRUE----------------------------------------------------------------
 adae <- mutate(adae, TRTP = TRT01P, TRTA = TRT01A)
@@ -128,7 +128,6 @@ adae <- mutate(adae, TRTP = TRT01P, TRTA = TRT01A)
 count(adae, TRTP, TRTA, TRT01P, TRT01A)
 
 ## ----eval=TRUE----------------------------------------------------------------
-data(ex_single)
 ex_single <- derive_vars_dtm(
   ex_single,
   dtc = EXSTDTC,
@@ -270,7 +269,7 @@ dataset_vignette(
 )
 
 ## ----eval=TRUE----------------------------------------------------------------
-data("queries")
+queries <- admiral::queries
 
 ## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(queries)
