@@ -13,15 +13,18 @@ library(lubridate)
 # Use e.g. haven::read_sas to read in .sas7bdat, or other suitable functions
 # as needed and assign to the variables below.
 # For illustration purposes read in admiral test data
-data("mh")
-data("admiral_adsl")
-data("queries_mh")
 
-adsl <- admiral_adsl
+mh <- pharmaversesdtm::mh
+queries_mh <- admiral::queries_mh
+adsl <- admiral::admiral_adsl
+
+# When SAS datasets are imported into R using haven::read_sas(), missing
+# character values from SAS appear as "" characters in R, instead of appearing
+# as NA values. Further details can be obtained via the following link:
+# https://pharmaverse.github.io/admiral/articles/admiral.html#handling-of-missing-values # nolint
 
 mh <- convert_blanks_to_na(mh)
 
-
 # Look-up tables ----
 
 # Creating a look-up table for assigning MHTERMN (for derivation of company specific variable)
@@ -122,14 +125,14 @@ admh <- mh %>%
   mutate(ANL01FL = ifelse(MHOCCUR != "N", "Y", NA_character_)) %>%
   ## Assign TRTA, TRTP (company specific variables derivation) ----
   # See also the "Visit and Period Variables" vignette
-  # (https://pharmaverse.github.io/admiral/cran-release/articles/visits_periods.html#treatment_bds)
+  # (https://pharmaverse.github.io/admiral/articles/visits_periods.html#treatment_bds)
   mutate(
     TRTP = TRT01P,
     TRTA = TRT01A
   ) %>%
   ## Assign APHASE and APHASEN Variable (company specific variable derivation) ----
   # See also the "Visit and Period Variables" vignette
-  # (https://pharmaverse.github.io/admiral/cran-release/articles/visits_periods.html#periods_bds)
+  # (https://pharmaverse.github.io/admiral/articles/visits_periods.html#periods_bds)
   mutate(
     APHASE = case_when(
       ADT < TRTSDT ~ "Screening",
@@ -169,5 +172,10 @@ admh <- admh %>%
 
 # Save output ----
 
-dir <- tempdir() # Change to whichever directory you want to save the dataset in
-saveRDS(admh, file = file.path(dir, "admh.rds"), compress = "bzip2")
+# Change to whichever directory you want to save the dataset in
+dir <- tools::R_user_dir("admiral_templates_data", which = "cache")
+if (!file.exists(dir)) {
+  # Create the folder
+  dir.create(dir, recursive = TRUE, showWarnings = FALSE)
+}
+save(admh, file = file.path(dir, "admh.rda"), compress = "bzip2")
