@@ -32,7 +32,7 @@ test_that("derive_locf_records Test 1: visits are missing", {
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     order = exprs(AVISITN, AVISIT)
   )
@@ -82,7 +82,7 @@ test_that("derive_locf_records Test 2: some visits have missing AVAL", {
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     order = exprs(AVISITN, AVISIT)
   )
@@ -142,7 +142,7 @@ test_that("derive_locf_records Test 3: visits are missing - and DTYPE already ex
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     order = exprs(AVISITN, AVISIT)
   )
@@ -190,7 +190,7 @@ test_that("derive_locf_records Test 4: visit variables are parameter independent
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     order = exprs(AVISITN, AVISIT)
   )
@@ -246,7 +246,7 @@ test_that("derive_locf_records Test 5: visit variables are parameter dependent",
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     order = exprs(AVISITN, AVISIT)
   )
@@ -290,7 +290,7 @@ test_that("derive_locf_records Test 6: populate VISITNUM for LOCF records", {
 
   actual_output <- derive_locf_records(
     input,
-    dataset_expected_obs = advs_expected_obsv,
+    dataset_ref = advs_expected_obsv,
     by_vars = exprs(STUDYID, USUBJID, PARAM, PARAMCD),
     analysis_var = AVALC,
     order = exprs(AVISITN, AVISIT),
