@@ -105,42 +105,7 @@ test_that("derive_summary_records Test 3: Errors", {
   )
 })
 
-## Test 4: deprecation warning for analysis_var and summary_fun ----
-test_that("derive_summary_records Test 4: deprecation warning for analysis_var and summary_fun", {
-  input <- tibble::tribble(
-    ~subj, ~visit,       ~val, ~seq,
-    "1",        1,         10,    1,
-    "1",        1,         14,    2,
-    "1",        1,          9,    3,
-    "1",        2,         11,    4,
-    "2",        2,   NA_real_,    1
-  )
-
-  expected_output <- bind_rows(
-    input,
-    tibble::tribble(
-      ~subj, ~visit,       ~val,
-      "1",        1,         11,
-      "1",        2,         11,
-      "2",        2,   NA_real_
-    ) %>%
-      mutate(type = "AVERAGE")
-  )
-
-  expect_error(
-    actual_output <- input %>%
-      derive_summary_records(
-        dataset_add = input,
-        by_vars = exprs(subj, visit),
-        analysis_var = val,
-        summary_fun = mean,
-        set_values_to = exprs(type = "AVERAGE")
-      ),
-    class = "lifecycle_error_deprecated"
-  )
-})
-
-## Test 5: make sure dataset_add works ----
+## Test 4: make sure dataset_add works ----
 test_that("derive_summary_records Test 5: make sure dataset_add works", {
   input <- tibble::tribble(
     ~subj, ~visit,       ~val, ~seq,
@@ -179,7 +144,7 @@ test_that("derive_summary_records Test 5: make sure dataset_add works", {
   )
 })
 
-## Test 6: test missing values ----
+## Test 5: test missing values ----
 test_that("derive_summary_records Test 6: test missing values with dataset_ref", {
   input <- tibble::tribble(
     ~subj, ~visit,       ~val, ~seq,
