@@ -1,6 +1,64 @@
-# dthcaus_source ----
-## Test 1: error on invalid mode ----
-test_that("dthcaus_source Test 1: error on invalid mode", {
+## Test 1: deprecation message if function is called ----
+test_that("derive_var_dthcaus Test 1: deprecation message if function is called", {
+  adsl <- tibble::tribble(
+    ~STUDYID, ~USUBJID,
+    "TEST01", "PAT01",
+    "TEST01", "PAT02",
+    "TEST01", "PAT03"
+  )
+
+  ae <- tibble::tribble(
+    ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
+    "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
+  ) %>%
+    mutate(
+      AEDTHDT = ymd(AEDTHDTC)
+    )
+
+  ds <- tibble::tribble(
+    ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
+    "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
+    "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT01", 3, "ADVERSE EVENT", "ADVERSE EVENT", "2021-12-01",
+    "TEST01", "PAT01", 4, "DEATH", "DEATH DUE TO progression of disease", "2022-02-01",
+    "TEST01", "PAT02", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-02",
+    "TEST01", "PAT02", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT02", 3, "COMPLETED", "PROTOCOL COMPLETED", "2021-12-01",
+    "TEST01", "PAT03", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-03",
+    "TEST01", "PAT03", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT03", 3, "COMPLETED", "PROTOCOL COMPLETED", "2021-12-01"
+  )
+
+  expect_snapshot({
+    src_ae <- dthcaus_source(
+      dataset_name = "ae",
+      filter = AEOUT == "FATAL",
+      date = AEDTHDT,
+      mode = "first",
+      dthcaus = AEDECOD
+    )
+
+    src_ds <- dthcaus_source(
+      dataset_name = "ds",
+      filter = DSDECOD == "DEATH" & grepl("DEATH DUE TO", DSTERM),
+      date = convert_dtc_to_dt(DSSTDTC),
+      mode = "first",
+      dthcaus = str_to_upper(DSTERM)
+    )
+
+    derive_var_dthcaus(
+      adsl,
+      source_datasets = list(ae = ae, ds = ds),
+      src_ae, src_ds
+    )
+  })
+})
+
+## Test 2: error on invalid mode ----
+test_that("derive_var_dthcaus Test 2: error on invalid mode", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   expect_error(dthcaus_source(
     dataset_name = "ae",
     filter = AEOUT == "FATAL",
@@ -11,8 +69,11 @@ test_that("dthcaus_source Test 1: error on invalid mode", {
 })
 
 # derive_var_dthcaus ----
-## Test 2: DTHCAUS is added from AE and DS ----
-test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
+## Test 3: DTHCAUS is added from AE and DS ----
+test_that("derive_var_dthcaus Test 3: DTHCAUS is added from AE and DS", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
@@ -74,8 +135,11 @@ test_that("derive_var_dthcaus Test 2: DTHCAUS is added from AE and DS", {
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 3: `dthcaus` handles symbols and string literals correctly ----
-test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string literals correctly", {
+## Test 4: `dthcaus` handles symbols and string literals correctly ----
+test_that("derive_var_dthcaus Test 4: `dthcaus` handles symbols and string literals correctly", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
@@ -135,8 +199,11 @@ test_that("derive_var_dthcaus Test 3: `dthcaus` handles symbols and string liter
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 4: traceability variables are added from AE and DS ----
-test_that("derive_var_dthcaus Test 4: traceability variables are added from AE and DS", {
+## Test 5: traceability variables are added from AE and DS ----
+test_that("derive_var_dthcaus Test 5: traceability variables are added from AE and DS", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
@@ -203,8 +270,11 @@ test_that("derive_var_dthcaus Test 4: traceability variables are added from AE a
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 5: DTHCAUS/traceabiity are added from 2 input datasets ----
-test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input datasets", {
+## Test 6: DTHCAUS/traceabiity are added from 2 input datasets ----
+test_that("derive_var_dthcaus Test 6: DTHCAUS/traceabiity are added from 2 input datasets", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
@@ -272,8 +342,11 @@ test_that("derive_var_dthcaus Test 5: DTHCAUS/traceabiity are added from 2 input
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 6: DTHCAUS is added from AE and DS if filter is not specified ----
-test_that("derive_var_dthcaus Test 6: DTHCAUS is added from AE and DS if filter is not specified", {
+## Test 7: DTHCAUS is added from AE and DS if filter is not specified ----
+test_that("derive_var_dthcaus Test 7: DTHCAUS is added from AE and DS if filter is not specified", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   # test based on covr report - the case for unspecified filter has not been tested
 
   adsl <- tibble::tribble(
@@ -340,8 +413,11 @@ test_that("derive_var_dthcaus Test 6: DTHCAUS is added from AE and DS if filter
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 7: error on a dthcaus_source object with invalid order ----
-test_that("derive_var_dthcaus Test 7: error on a dthcaus_source object with invalid order", {
+## Test 8: error on a dthcaus_source object with invalid order ----
+test_that("derive_var_dthcaus Test 8: error on a dthcaus_source object with invalid order", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   expect_error(dthcaus_source(
     dataset_name = "ae",
     filter = AEOUT == "FATAL",
@@ -352,8 +428,11 @@ test_that("derive_var_dthcaus Test 7: error on a dthcaus_source object with inva
   ))
 })
 
-## Test 8: `dataset` is sorted using the `order` parameter ----
-test_that("derive_var_dthcaus Test 8: `dataset` is sorted using the `order` parameter", {
+## Test 9: `dataset` is sorted using the `order` parameter ----
+test_that("derive_var_dthcaus Test 9: `dataset` is sorted using the `order` parameter", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
@@ -414,8 +493,11 @@ test_that("derive_var_dthcaus Test 8: `dataset` is sorted using the `order` para
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 9: multiple observations from different sources ----
-test_that("derive_var_dthcaus Test 9: multiple observations from different sources", {
+## Test 10: multiple observations from different sources ----
+test_that("derive_var_dthcaus Test 10: multiple observations from different sources", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   expected <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01",  "SUDDEN DEATH",
@@ -470,8 +552,11 @@ test_that("derive_var_dthcaus Test 9: multiple observations from different sourc
   )
 })
 
-## Test 10: multiple observations with same date ----
-test_that("derive_var_dthcaus Test 10: multiple observations with same date", {
+## Test 11: multiple observations with same date ----
+test_that("derive_var_dthcaus Test 11: multiple observations with same date", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   expected <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01",  "SUDDEN DEATH",
@@ -526,8 +611,11 @@ test_that("derive_var_dthcaus Test 10: multiple observations with same date", {
   )
 })
 
-## Test 11: error if source dataset is not available ----
-test_that("derive_var_dthcaus Test 11: error if source dataset is not available", {
+## Test 12: error if source dataset is not available ----
+test_that("derive_var_dthcaus Test 12: error if source dataset is not available", {
+  # Suppress lifecycle messages within the test environment
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+
   adsl <- tibble::tribble(
     ~STUDYID, ~USUBJID,
     "TEST01", "PAT01",
